#
# spec file for package python-incremental
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-incremental%{psuffix}
Version:        24.7.2
Release:        1.1
Summary:        Library that versions your Python projects
License:        MIT
URL:            https://github.com/twisted/incremental
Source:         https://files.pythonhosted.org/packages/source/i/incremental/incremental-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-Twisted >= 16.4.0
Suggests:       python-click >= 6.0
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Twisted >= 16.4.0}
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module click >= 6.0}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
Incremental is a small library that versions your Python projects.

%prep
%setup -q -n incremental-%{version}

%build
%pyproject_wheel

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# See: https://github.com/twisted/incremental/issues/110
%pytest -k 'not test_examples.py'
%endif

%if %{without test}
%files %{python_files}
%license LICENSE
%doc NEWS.rst README.rst
%{python_sitelib}/incremental
%{python_sitelib}/incremental-%{version}*-info
%endif

%changelog
* Tue Sep 17 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 24.7.2
  * Incremental could mis-identify that a project had opted in to version management.
- from version 24.7.1
  * Incremental 24.7.0 would produce an error when parsing the ``pyproject.toml`` of
    a project that lacked the ``use_incremental=True`` or ``[tool.incremental]`` opt-in
    markers if that file lacked a ``[project]`` section containing the package name.
    This could cause a project that only uses ``pyproject.toml`` to configure tools to
    fail to build if Incremental is installed. Incremental now ignores such projects. (#100)
  * Fix issue #101
- from version 24.7.0
  * Incremental can now be configured using ``pyproject.toml``. (#90)
  * Incremental now provides a read-only `Hatchling version source plugin (#93)
  * Incremental no longer inserts a dot before the rc version component (i.e., ``1.2.3rc1``
    instead of ``1.2.3.rc1``), resulting in version numbers in the `canonical format. (#81)
  * Incremental's tests are now included in the sdist release artifact. (#80)
  * ``incremental[scripts]`` no longer depends on Twisted. (#88)
  * Support for Python 2.7 has been dropped for lack of test infrastructure.
    We no longer provide universal wheels. (#86)
  * Support for Python 3.5, 3.6, and 3.7 has been
    dropped for lack of test infrastructure. (#92)
- Limit Python files matched in %%files section
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Allow test_prereleaseAttributeDeprecated and test_prereleaseDeprecated tests again
- Skip tests from skip_examples.py
- Update BuildRequires from pyproject.toml
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Sun Oct 16 2022 Dirk Müller <dmueller@suse.com>
- update to 22.10.0:
  * Incremental now supports type-checking with Mypy (#69)
* Thu Dec 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not use %%{python_module …} for suggests, as this would suggest
  all python flavors. Rather rely on the python singlespec macros
  to rewrite as needed.
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 21.3.0:
  - The output of incremental is now compatible with Black (#56, #60)
  - Incremental now properly supports PEP 440-compliant dev, rc, post suffixes (#62)
  - Incremental now properly supports PEP 440-compliant post releases (#37)
  - Incremental will no longer attempt to read git or svn repositories to see if
    the project is running from a checkout. (#30, #31, #32)
* Wed Apr 29 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip two tests that fail due to changes in pytest framework
  needs to be fixed by upstream
* Thu Jun  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to multibuild to avoid build cycle
* Wed Jun  5 2019 pgajdos@suse.com
- run the testsuite
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Jul  4 2017 tbechtold@suse.com
- Initial packaging (version 17.5.0)
